==> jekyll-md-highlight-parser-1.1.3.tgz: package/index.js <==
function hParse(string) {
  return string
    .replace(/{% endhighlight %}/g, "~~~")
    .replace(/{% highlight log %}/g, "~~~")
    .replace(/{% highlight text %}/g, "~~~")
    .replace(/{% highlight plain %}/g, "~~~")
    .replace(/{% highlight oneC %}/g, "~~~oneC")
    .replace(/{% highlight abnf %}/g, "~~~abnf")
    .replace(/{% highlight accesslog %}/g, "~~~accesslog")
    .replace(/{% highlight actionscript %}/g, "~~~actionscript")
    .replace(/{% highlight ada %}/g, "~~~ada")
    .replace(/{% highlight angelscript %}/g, "~~~angelscript")
    .replace(/{% highlight apache %}/g, "~~~apache")
    .replace(/{% highlight applescript %}/g, "~~~applescript")
    .replace(/{% highlight arcade %}/g, "~~~arcade")
    .replace(/{% highlight arduino %}/g, "~~~arduino")
    .replace(/{% highlight armasm %}/g, "~~~armasm")
    .replace(/{% highlight asciidoc %}/g, "~~~asciidoc")
    .replace(/{% highlight aspectj %}/g, "~~~aspectj")
    .replace(/{% highlight autohotkey %}/g, "~~~autohotkey")
    .replace(/{% highlight autoit %}/g, "~~~autoit")
    .replace(/{% highlight avrasm %}/g, "~~~avrasm")
    .replace(/{% highlight awk %}/g, "~~~awk")
    .replace(/{% highlight axapta %}/g, "~~~axapta")
    .replace(/{% highlight bash %}/g, "~~~bash")
    .replace(/{% highlight basic %}/g, "~~~basic")
    .replace(/{% highlight bnf %}/g, "~~~bnf")
    .replace(/{% highlight brainfuck %}/g, "~~~brainfuck")
    .replace(/{% highlight cLike %}/g, "~~~cLike")
    .replace(/{% highlight c %}/g, "~~~c")
    .replace(/{% highlight cal %}/g, "~~~cal")
    .replace(/{% highlight capnproto %}/g, "~~~capnproto")
    .replace(/{% highlight ceylon %}/g, "~~~ceylon")
    .replace(/{% highlight clean %}/g, "~~~clean")
    .replace(/{% highlight clojureRepl %}/g, "~~~clojureRepl")
    .replace(/{% highlight clojure %}/g, "~~~clojure")
    .replace(/{% highlight cmake %}/g, "~~~cmake")
    .replace(/{% highlight coffeescript %}/g, "~~~coffeescript")
    .replace(/{% highlight coq %}/g, "~~~coq")
    .replace(/{% highlight cos %}/g, "~~~cos")
    .replace(/{% highlight cpp %}/g, "~~~cpp")
    .replace(/{% highlight crmsh %}/g, "~~~crmsh")
    .replace(/{% highlight crystal %}/g, "~~~crystal")
    .replace(/{% highlight csharp %}/g, "~~~csharp")
    .replace(/{% highlight csp %}/g, "~~~csp")
    .replace(/{% highlight css %}/g, "~~~css")
    .replace(/{% highlight d %}/g, "~~~d")
    .replace(/{% highlight dart %}/g, "~~~dart")
    .replace(/{% highlight delphi %}/g, "~~~delphi")
    .replace(/{% highlight diff %}/g, "~~~diff")
    .replace(/{% highlight django %}/g, "~~~django")
    .replace(/{% highlight dns %}/g, "~~~dns")
    .replace(/{% highlight dockerfile %}/g, "~~~dockerfile")
    .replace(/{% highlight dos %}/g, "~~~dos")
    .replace(/{% highlight dsconfig %}/g, "~~~dsconfig")
    .replace(/{% highlight dts %}/g, "~~~dts")
    .replace(/{% highlight dust %}/g, "~~~dust")
    .replace(/{% highlight ebnf %}/g, "~~~ebnf")
    .replace(/{% highlight elixir %}/g, "~~~elixir")
    .replace(/{% highlight elm %}/g, "~~~elm")
    .replace(/{% highlight erb %}/g, "~~~erb")
    .replace(/{% highlight erlangRepl %}/g, "~~~erlangRepl")
    .replace(/{% highlight erlang %}/g, "~~~erlang")
    .replace(/{% highlight excel %}/g, "~~~excel")
    .replace(/{% highlight fix %}/g, "~~~fix")
    .replace(/{% highlight flix %}/g, "~~~flix")
    .replace(/{% highlight fortran %}/g, "~~~fortran")
    .replace(/{% highlight fsharp %}/g, "~~~fsharp")
    .replace(/{% highlight gams %}/g, "~~~gams")
    .replace(/{% highlight gauss %}/g, "~~~gauss")
    .replace(/{% highlight gcode %}/g, "~~~gcode")
    .replace(/{% highlight gherkin %}/g, "~~~gherkin")
    .replace(/{% highlight glsl %}/g, "~~~glsl")
    .replace(/{% highlight gml %}/g, "~~~gml")
    .replace(/{% highlight go %}/g, "~~~go")
    .replace(/{% highlight golo %}/g, "~~~golo")
    .replace(/{% highlight gradle %}/g, "~~~gradle")
    .replace(/{% highlight groovy %}/g, "~~~groovy")
    .replace(/{% highlight haml %}/g, "~~~haml")
    .replace(/{% highlight html %}/g, "~~~html")
    .replace(/{% highlight handlebars %}/g, "~~~handlebars")
    .replace(/{% highlight html[+]handlebars %}/g, "~~~handlebars")
    .replace(/{% highlight haskell %}/g, "~~~haskell")
    .replace(/{% highlight haxe %}/g, "~~~haxe")
    .replace(/{% highlight hsp %}/g, "~~~hsp")
    .replace(/{% highlight htmlbars %}/g, "~~~htmlbars")
    .replace(/{% highlight http %}/g, "~~~http")
    .replace(/{% highlight hy %}/g, "~~~hy")
    .replace(/{% highlight inform7 %}/g, "~~~inform7")
    .replace(/{% highlight ini %}/g, "~~~ini")
    .replace(/{% highlight irpf90 %}/g, "~~~irpf90")
    .replace(/{% highlight isbl %}/g, "~~~isbl")
    .replace(/{% highlight java %}/g, "~~~java")
    .replace(/{% highlight js %}/g, "~~~javascript")
    .replace(/{% highlight javascript %}/g, "~~~javascript")
    .replace(/{% highlight jbossCli %}/g, "~~~jbossCli")
    .replace(/{% highlight json %}/g, "~~~json")
    .replace(/{% highlight juliaRepl %}/g, "~~~juliaRepl")
    .replace(/{% highlight julia %}/g, "~~~julia")
    .replace(/{% highlight kotlin %}/g, "~~~kotlin")
    .replace(/{% highlight lasso %}/g, "~~~lasso")
    .replace(/{% highlight latex %}/g, "~~~latex")
    .replace(/{% highlight ldif %}/g, "~~~ldif")
    .replace(/{% highlight leaf %}/g, "~~~leaf")
    .replace(/{% highlight less %}/g, "~~~less")
    .replace(/{% highlight lisp %}/g, "~~~lisp")
    .replace(/{% highlight livecodeserver %}/g, "~~~livecodeserver")
    .replace(/{% highlight livescript %}/g, "~~~livescript")
    .replace(/{% highlight llvm %}/g, "~~~llvm")
    .replace(/{% highlight lsl %}/g, "~~~lsl")
    .replace(/{% highlight lua %}/g, "~~~lua")
    .replace(/{% highlight makefile %}/g, "~~~makefile")
    .replace(/{% highlight markdown %}/g, "~~~markdown")
    .replace(/{% highlight mathematica %}/g, "~~~mathematica")
    .replace(/{% highlight matlab %}/g, "~~~matlab")
    .replace(/{% highlight maxima %}/g, "~~~maxima")
    .replace(/{% highlight mel %}/g, "~~~mel")
    .replace(/{% highlight mercury %}/g, "~~~mercury")
    .replace(/{% highlight mipsasm %}/g, "~~~mipsasm")
    .replace(/{% highlight mizar %}/g, "~~~mizar")
    .replace(/{% highlight mojolicious %}/g, "~~~mojolicious")
    .replace(/{% highlight monkey %}/g, "~~~monkey")
    .replace(/{% highlight moonscript %}/g, "~~~moonscript")
    .replace(/{% highlight n1ql %}/g, "~~~n1ql")
    .replace(/{% highlight nginx %}/g, "~~~nginx")
    .replace(/{% highlight nim %}/g, "~~~nim")
    .replace(/{% highlight nix %}/g, "~~~nix")
    .replace(/{% highlight nsis %}/g, "~~~nsis")
    .replace(/{% highlight objectivec %}/g, "~~~objectivec")
    .replace(/{% highlight objective-c %}/g, "~~~objectivec")
    .replace(/{% highlight ocaml %}/g, "~~~ocaml")
    .replace(/{% highlight openscad %}/g, "~~~openscad")
    .replace(/{% highlight oxygene %}/g, "~~~oxygene")
    .replace(/{% highlight parser3 %}/g, "~~~parser3")
    .replace(/{% highlight perl %}/g, "~~~perl")
    .replace(/{% highlight pf %}/g, "~~~pf")
    .replace(/{% highlight pgsql %}/g, "~~~pgsql")
    .replace(/{% highlight phpTemplate %}/g, "~~~phpTemplate")
    .replace(/{% highlight php %}/g, "~~~php")
    .replace(/{% highlight plaintext %}/g, "~~~plaintext")
    .replace(/{% highlight pony %}/g, "~~~pony")
    .replace(/{% highlight powershell %}/g, "~~~powershell")
    .replace(/{% highlight processing %}/g, "~~~processing")
    .replace(/{% highlight profile %}/g, "~~~profile")
    .replace(/{% highlight prolog %}/g, "~~~prolog")
    .replace(/{% highlight properties %}/g, "~~~properties")
    .replace(/{% highlight protobuf %}/g, "~~~protobuf")
    .replace(/{% highlight puppet %}/g, "~~~puppet")
    .replace(/{% highlight purebasic %}/g, "~~~purebasic")
    .replace(/{% highlight pythonRepl %}/g, "~~~pythonRepl")
    .replace(/{% highlight python %}/g, "~~~python")
    .replace(/{% highlight q %}/g, "~~~q")
    .replace(/{% highlight qml %}/g, "~~~qml")
    .replace(/{% highlight r %}/g, "~~~r")
    .replace(/{% highlight reasonml %}/g, "~~~reasonml")
    .replace(/{% highlight rib %}/g, "~~~rib")
    .replace(/{% highlight roboconf %}/g, "~~~roboconf")
    .replace(/{% highlight routeros %}/g, "~~~routeros")
    .replace(/{% highlight rsl %}/g, "~~~rsl")
    .replace(/{% highlight ruby %}/g, "~~~ruby")
    .replace(/{% highlight ruleslanguage %}/g, "~~~ruleslanguage")
    .replace(/{% highlight rust %}/g, "~~~rust")
    .replace(/{% highlight sas %}/g, "~~~sas")
    .replace(/{% highlight scala %}/g, "~~~scala")
    .replace(/{% highlight scheme %}/g, "~~~scheme")
    .replace(/{% highlight scilab %}/g, "~~~scilab")
    .replace(/{% highlight scss %}/g, "~~~scss")
    .replace(/{% highlight shell %}/g, "~~~shell")
    .replace(/{% highlight smali %}/g, "~~~smali")
    .replace(/{% highlight smalltalk %}/g, "~~~smalltalk")
    .replace(/{% highlight sml %}/g, "~~~sml")
    .replace(/{% highlight sqf %}/g, "~~~sqf")
    .replace(/{% highlight sql %}/g, "~~~sql")
    .replace(/{% highlight stan %}/g, "~~~stan")
    .replace(/{% highlight stata %}/g, "~~~stata")
    .replace(/{% highlight step21 %}/g, "~~~step21")
    .replace(/{% highlight stylus %}/g, "~~~stylus")
    .replace(/{% highlight subunit %}/g, "~~~subunit")
    .replace(/{% highlight swift %}/g, "~~~swift")
    .replace(/{% highlight taggerscript %}/g, "~~~taggerscript")
    .replace(/{% highlight tap %}/g, "~~~tap")
    .replace(/{% highlight tcl %}/g, "~~~tcl")
    .replace(/{% highlight thrift %}/g, "~~~thrift")
    .replace(/{% highlight tp %}/g, "~~~tp")
    .replace(/{% highlight twig %}/g, "~~~twig")
    .replace(/{% highlight typescript %}/g, "~~~typescript")
    .replace(/{% highlight vala %}/g, "~~~vala")
    .replace(/{% highlight vbnet %}/g, "~~~vbnet")
    .replace(/{% highlight vbscriptHtml %}/g, "~~~vbscriptHtml")
    .replace(/{% highlight vbscript %}/g, "~~~vbscript")
    .replace(/{% highlight verilog %}/g, "~~~verilog")
    .replace(/{% highlight vhdl %}/g, "~~~vhdl")
    .replace(/{% highlight vim %}/g, "~~~vim")
    .replace(/{% highlight x86asm %}/g, "~~~x86asm")
    .replace(/{% highlight xl %}/g, "~~~xl")
    .replace(/{% highlight xml %}/g, "~~~xml")
    .replace(/{% highlight xquery %}/g, "~~~xquery")
    .replace(/{% highlight yml %}/g, "~~~yaml")
    .replace(/{% highlight yaml %}/g, "~~~yaml")
    .replace(/{% highlight zephir %}/g, "~~~zephir");
}

function iParse(code, id) {
  if (code.includes("{% image")) {
    var image = `${id ? id : ""}/${code.split("{% image ")[1].split("alt")[0]}`;
    var alt = code.split("{% image ")[1].split("alt:'")[1]
      ? code.split("{% image ")[1].split("alt:'")[1].split("'")[0]
      : "";
    var value = `![${alt}](${image.replace(/"/g, "")})`;
    var output =
      code.split("{% image ")[0] +
      value +
      code.substr(
        code.split("{% image ")[0].length + image.length + alt.length + 6
      );
    return iParse(output);
  } else {
    return code;
  }
}

module.exports = {
  hParse,
  iParse,
};

==> jekyll-md-highlight-parser-1.1.4.tgz: package/index.js <==
function hParse(string) {
  return string
    .replace(/{% endhighlight %}/g, "~~~")
    .replace(/{% highlight log %}/g, "~~~")
    .replace(/{% highlight text %}/g, "~~~")
    .replace(/{% highlight plain %}/g, "~~~")
    .replace(/{% highlight oneC %}/g, "~~~oneC")
    .replace(/{% highlight abnf %}/g, "~~~abnf")
    .replace(/{% highlight accesslog %}/g, "~~~accesslog")
    .replace(/{% highlight actionscript %}/g, "~~~actionscript")
    .replace(/{% highlight ada %}/g, "~~~ada")
    .replace(/{% highlight angelscript %}/g, "~~~angelscript")
    .replace(/{% highlight apache %}/g, "~~~apache")
    .replace(/{% highlight applescript %}/g, "~~~applescript")
    .replace(/{% highlight arcade %}/g, "~~~arcade")
    .replace(/{% highlight arduino %}/g, "~~~arduino")
    .replace(/{% highlight armasm %}/g, "~~~armasm")
    .replace(/{% highlight asciidoc %}/g, "~~~asciidoc")
    .replace(/{% highlight aspectj %}/g, "~~~aspectj")
    .replace(/{% highlight autohotkey %}/g, "~~~autohotkey")
    .replace(/{% highlight autoit %}/g, "~~~autoit")
    .replace(/{% highlight avrasm %}/g, "~~~avrasm")
    .replace(/{% highlight awk %}/g, "~~~awk")
    .replace(/{% highlight axapta %}/g, "~~~axapta")
    .replace(/{% highlight bash %}/g, "~~~bash")
    .replace(/{% highlight basic %}/g, "~~~basic")
    .replace(/{% highlight bnf %}/g, "~~~bnf")
    .replace(/{% highlight brainfuck %}/g, "~~~brainfuck")
    .replace(/{% highlight cLike %}/g, "~~~cLike")
    .replace(/{% highlight c %}/g, "~~~c")
    .replace(/{% highlight cal %}/g, "~~~cal")
    .replace(/{% highlight capnproto %}/g, "~~~capnproto")
    .replace(/{% highlight ceylon %}/g, "~~~ceylon")
    .replace(/{% highlight clean %}/g, "~~~clean")
    .replace(/{% highlight clojureRepl %}/g, "~~~clojureRepl")
    .replace(/{% highlight clojure %}/g, "~~~clojure")
    .replace(/{% highlight cmake %}/g, "~~~cmake")
    .replace(/{% highlight coffeescript %}/g, "~~~coffeescript")
    .replace(/{% highlight coq %}/g, "~~~coq")
    .replace(/{% highlight cos %}/g, "~~~cos")
    .replace(/{% highlight cpp %}/g, "~~~cpp")
    .replace(/{% highlight crmsh %}/g, "~~~crmsh")
    .replace(/{% highlight crystal %}/g, "~~~crystal")
    .replace(/{% highlight csharp %}/g, "~~~csharp")
    .replace(/{% highlight csp %}/g, "~~~csp")
    .replace(/{% highlight css %}/g, "~~~css")
    .replace(/{% highlight d %}/g, "~~~d")
    .replace(/{% highlight dart %}/g, "~~~dart")
    .replace(/{% highlight delphi %}/g, "~~~delphi")
    .replace(/{% highlight diff %}/g, "~~~diff")
    .replace(/{% highlight django %}/g, "~~~django")
    .replace(/{% highlight dns %}/g, "~~~dns")
    .replace(/{% highlight dockerfile %}/g, "~~~dockerfile")
    .replace(/{% highlight dos %}/g, "~~~dos")
    .replace(/{% highlight dsconfig %}/g, "~~~dsconfig")
    .replace(/{% highlight dts %}/g, "~~~dts")
    .replace(/{% highlight dust %}/g, "~~~dust")
    .replace(/{% highlight ebnf %}/g, "~~~ebnf")
    .replace(/{% highlight elixir %}/g, "~~~elixir")
    .replace(/{% highlight elm %}/g, "~~~elm")
    .replace(/{% highlight erb %}/g, "~~~erb")
    .replace(/{% highlight erlangRepl %}/g, "~~~erlangRepl")
    .replace(/{% highlight erlang %}/g, "~~~erlang")
    .replace(/{% highlight excel %}/g, "~~~excel")
    .replace(/{% highlight fix %}/g, "~~~fix")
    .replace(/{% highlight flix %}/g, "~~~flix")
    .replace(/{% highlight fortran %}/g, "~~~fortran")
    .replace(/{% highlight fsharp %}/g, "~~~fsharp")
    .replace(/{% highlight gams %}/g, "~~~gams")
    .replace(/{% highlight gauss %}/g, "~~~gauss")
    .replace(/{% highlight gcode %}/g, "~~~gcode")
    .replace(/{% highlight gherkin %}/g, "~~~gherkin")
    .replace(/{% highlight glsl %}/g, "~~~glsl")
    .replace(/{% highlight gml %}/g, "~~~gml")
    .replace(/{% highlight go %}/g, "~~~go")
    .replace(/{% highlight golo %}/g, "~~~golo")
    .replace(/{% highlight gradle %}/g, "~~~gradle")
    .replace(/{% highlight groovy %}/g, "~~~groovy")
    .replace(/{% highlight haml %}/g, "~~~haml")
    .replace(/{% highlight html %}/g, "~~~html")
    .replace(/{% highlight handlebars %}/g, "~~~handlebars")
    .replace(/{% highlight html[+]handlebars %}/g, "~~~handlebars")
    .replace(/{% highlight haskell %}/g, "~~~haskell")
    .replace(/{% highlight haxe %}/g, "~~~haxe")
    .replace(/{% highlight hsp %}/g, "~~~hsp")
    .replace(/{% highlight htmlbars %}/g, "~~~htmlbars")
    .replace(/{% highlight http %}/g, "~~~http")
    .replace(/{% highlight hy %}/g, "~~~hy")
    .replace(/{% highlight inform7 %}/g, "~~~inform7")
    .replace(/{% highlight ini %}/g, "~~~ini")
    .replace(/{% highlight irpf90 %}/g, "~~~irpf90")
    .replace(/{% highlight isbl %}/g, "~~~isbl")
    .replace(/{% highlight java %}/g, "~~~java")
    .replace(/{% highlight js %}/g, "~~~javascript")
    .replace(/{% highlight javascript %}/g, "~~~javascript")
    .replace(/{% highlight jbossCli %}/g, "~~~jbossCli")
    .replace(/{% highlight json %}/g, "~~~json")
    .replace(/{% highlight juliaRepl %}/g, "~~~juliaRepl")
    .replace(/{% highlight julia %}/g, "~~~julia")
    .replace(/{% highlight kotlin %}/g, "~~~kotlin")
    .replace(/{% highlight lasso %}/g, "~~~lasso")
    .replace(/{% highlight latex %}/g, "~~~latex")
    .replace(/{% highlight ldif %}/g, "~~~ldif")
    .replace(/{% highlight leaf %}/g, "~~~leaf")
    .replace(/{% highlight less %}/g, "~~~less")
    .replace(/{% highlight lisp %}/g, "~~~lisp")
    .replace(/{% highlight livecodeserver %}/g, "~~~livecodeserver")
    .replace(/{% highlight livescript %}/g, "~~~livescript")
    .replace(/{% highlight llvm %}/g, "~~~llvm")
    .replace(/{% highlight lsl %}/g, "~~~lsl")
    .replace(/{% highlight lua %}/g, "~~~lua")
    .replace(/{% highlight makefile %}/g, "~~~makefile")
    .replace(/{% highlight markdown %}/g, "~~~markdown")
    .replace(/{% highlight mathematica %}/g, "~~~mathematica")
    .replace(/{% highlight matlab %}/g, "~~~matlab")
    .replace(/{% highlight maxima %}/g, "~~~maxima")
    .replace(/{% highlight mel %}/g, "~~~mel")
    .replace(/{% highlight mercury %}/g, "~~~mercury")
    .replace(/{% highlight mipsasm %}/g, "~~~mipsasm")
    .replace(/{% highlight mizar %}/g, "~~~mizar")
    .replace(/{% highlight mojolicious %}/g, "~~~mojolicious")
    .replace(/{% highlight monkey %}/g, "~~~monkey")
    .replace(/{% highlight moonscript %}/g, "~~~moonscript")
    .replace(/{% highlight n1ql %}/g, "~~~n1ql")
    .replace(/{% highlight nginx %}/g, "~~~nginx")
    .replace(/{% highlight nim %}/g, "~~~nim")
    .replace(/{% highlight nix %}/g, "~~~nix")
    .replace(/{% highlight nsis %}/g, "~~~nsis")
    .replace(/{% highlight objectivec %}/g, "~~~objectivec")
    .replace(/{% highlight objective-c %}/g, "~~~objectivec")
    .replace(/{% highlight ocaml %}/g, "~~~ocaml")
    .replace(/{% highlight openscad %}/g, "~~~openscad")
    .replace(/{% highlight oxygene %}/g, "~~~oxygene")
    .replace(/{% highlight parser3 %}/g, "~~~parser3")
    .replace(/{% highlight perl %}/g, "~~~perl")
    .replace(/{% highlight pf %}/g, "~~~pf")
    .replace(/{% highlight pgsql %}/g, "~~~pgsql")
    .replace(/{% highlight phpTemplate %}/g, "~~~phpTemplate")
    .replace(/{% highlight php %}/g, "~~~php")
    .replace(/{% highlight plaintext %}/g, "~~~plaintext")
    .replace(/{% highlight pony %}/g, "~~~pony")
    .replace(/{% highlight powershell %}/g, "~~~powershell")
    .replace(/{% highlight processing %}/g, "~~~processing")
    .replace(/{% highlight profile %}/g, "~~~profile")
    .replace(/{% highlight prolog %}/g, "~~~prolog")
    .replace(/{% highlight properties %}/g, "~~~properties")
    .replace(/{% highlight protobuf %}/g, "~~~protobuf")
    .replace(/{% highlight puppet %}/g, "~~~puppet")
    .replace(/{% highlight purebasic %}/g, "~~~purebasic")
    .replace(/{% highlight pythonRepl %}/g, "~~~pythonRepl")
    .replace(/{% highlight python %}/g, "~~~python")
    .replace(/{% highlight q %}/g, "~~~q")
    .replace(/{% highlight qml %}/g, "~~~qml")
    .replace(/{% highlight r %}/g, "~~~r")
    .replace(/{% highlight reasonml %}/g, "~~~reasonml")
    .replace(/{% highlight rib %}/g, "~~~rib")
    .replace(/{% highlight roboconf %}/g, "~~~roboconf")
    .replace(/{% highlight routeros %}/g, "~~~routeros")
    .replace(/{% highlight rsl %}/g, "~~~rsl")
    .replace(/{% highlight ruby %}/g, "~~~ruby")
    .replace(/{% highlight ruleslanguage %}/g, "~~~ruleslanguage")
    .replace(/{% highlight rust %}/g, "~~~rust")
    .replace(/{% highlight sas %}/g, "~~~sas")
    .replace(/{% highlight scala %}/g, "~~~scala")
    .replace(/{% highlight scheme %}/g, "~~~scheme")
    .replace(/{% highlight scilab %}/g, "~~~scilab")
    .replace(/{% highlight scss %}/g, "~~~scss")
    .replace(/{% highlight shell %}/g, "~~~shell")
    .replace(/{% highlight smali %}/g, "~~~smali")
    .replace(/{% highlight smalltalk %}/g, "~~~smalltalk")
    .replace(/{% highlight sml %}/g, "~~~sml")
    .replace(/{% highlight sqf %}/g, "~~~sqf")
    .replace(/{% highlight sql %}/g, "~~~sql")
    .replace(/{% highlight stan %}/g, "~~~stan")
    .replace(/{% highlight stata %}/g, "~~~stata")
    .replace(/{% highlight step21 %}/g, "~~~step21")
    .replace(/{% highlight stylus %}/g, "~~~stylus")
    .replace(/{% highlight subunit %}/g, "~~~subunit")
    .replace(/{% highlight swift %}/g, "~~~swift")
    .replace(/{% highlight taggerscript %}/g, "~~~taggerscript")
    .replace(/{% highlight tap %}/g, "~~~tap")
    .replace(/{% highlight tcl %}/g, "~~~tcl")
    .replace(/{% highlight thrift %}/g, "~~~thrift")
    .replace(/{% highlight tp %}/g, "~~~tp")
    .replace(/{% highlight twig %}/g, "~~~twig")
    .replace(/{% highlight typescript %}/g, "~~~typescript")
    .replace(/{% highlight vala %}/g, "~~~vala")
    .replace(/{% highlight vbnet %}/g, "~~~vbnet")
    .replace(/{% highlight vbscriptHtml %}/g, "~~~vbscriptHtml")
    .replace(/{% highlight vbscript %}/g, "~~~vbscript")
    .replace(/{% highlight verilog %}/g, "~~~verilog")
    .replace(/{% highlight vhdl %}/g, "~~~vhdl")
    .replace(/{% highlight vim %}/g, "~~~vim")
    .replace(/{% highlight x86asm %}/g, "~~~x86asm")
    .replace(/{% highlight xl %}/g, "~~~xl")
    .replace(/{% highlight xml %}/g, "~~~xml")
    .replace(/{% highlight xquery %}/g, "~~~xquery")
    .replace(/{% highlight yml %}/g, "~~~yaml")
    .replace(/{% highlight yaml %}/g, "~~~yaml")
    .replace(/{% highlight zephir %}/g, "~~~zephir");
}

function iParse(code, id) {
  if (code.includes("{% image") && code.includes("alt:'")) {
    var image = `${id ? id : ""}/${code.split("{% image ")[1].split("alt")[0]}`;
    var alt = code.split("{% image ")[1].split("alt:'")[1].split("'")[0];
    var value = `![${alt}](${image.replace(/"/g, "")})`;
    var output =
      code.split("{% image ")[0] +
      value +
      code.substr(
        code.split("{% image ")[0].length + image.length + alt.length + 6
      );
    return iParse(output, id);
  } else {
    return code;
  }
}

module.exports = {
  hParse,
  iParse,
};
